pub(crate) fn inline_modules<T>(expr: At<T>) -> At<T::Out>where
T: AstNode + Foldable<DefaultTypes, DefaultTypes>,
T::Out: AstNode,Expand description
Inlines modules at a given T relative to the PWD
pub(crate) fn inline_modules<T>(expr: At<T>) -> At<T::Out>where
T: AstNode + Foldable<DefaultTypes, DefaultTypes>,
T::Out: AstNode,Inlines modules at a given T relative to the PWD